==> kexi_3.1.0.orig.tar.xz: kexi-3.1.0/src/data/org.kde.kexi.desktop.cmake <==
[Desktop Entry]
Name=Kexi
Name[ast]=Kexi
Name[ca]=Kexi
Name[ca@valencia]=Kexi
Name[cs]=Kexi
Name[de]=Kexi
Name[en_GB]=Kexi
Name[es]=Kexi
Name[fi]=Kexi
Name[fr]=Kexi
Name[gl]=Kexi
Name[ia]=Kexi
Name[it]=Kexi
Name[ja]=Kexi
Name[nb]=Kexi
Name[nl]=Kexi
Name[pl]=Kexi
Name[pt]=Kexi
Name[pt_BR]=Kexi
Name[ru]=Kexi
Name[se]=Kexi
Name[sk]=Kexi
Name[sv]=Kexi
Name[uk]=Kexi
Name[x-test]=xxKexixx
Name[zh_CN]=Kexi
Type=Application
Exec=kexi-@KEXI_DISTRIBUTION_VERSION@ %f
Icon=kexi
MimeType=application/x-kexiproject-sqlite;application/x-kexiproject-shortcut;application/x-kexiproject-sqlite3;application/x-sqlite3;application/x-kexi-connectiondata;text/csv;text/tab-separated-values;application/vnd.oasis.opendocument.spreadsheet;application/vnd.oasis.opendocument.text;application/x-msaccess;application/vnd.oasis.opendocument.database;
Terminal=false
GenericName=Visual database apps builder
GenericName[ca]=Constructor visual d'aplicacions de bases de dades
GenericName[ca@valencia]=Constructor visual d'aplicacions de bases de dades
GenericName[de]=Visuelle Erstellung von Datenbankanwendungen
GenericName[en_GB]=Visual database apps builder
GenericName[es]=Constructor visual de aplicaciones de bases de datos
GenericName[fi]=Visuaalinen tietokantasovellusten luonti
GenericName[fr]=Constructeur d'applications de bases de données visuel
GenericName[gl]=Construtor visual de aplicativos de base de datos
GenericName[it]=Generatore visuale di applicazioni di banche dati
GenericName[nl]=Visuele database van bouwer van apps
GenericName[pl]=Tworzenie wizualnych aplikacji baz danych
GenericName[pt]=Construtor visual de aplicações de bases de dados
GenericName[pt_BR]=Construtor visual de aplicativos de banco de dados
GenericName[sk]=Vizuálny tvorca databázových aplikácií
GenericName[sv]=Visuellt byggverktyg för databasprogram
GenericName[uk]=Програма для побудови візуальних обробників баз даних
GenericName[x-test]=xxVisual database apps builderxx
Comment=Visually develop database applications
Comment[ca]=Desenvolupament visual d'aplicacions de bases de dades
Comment[ca@valencia]=Desenvolupament visual d'aplicacions de bases de dades
Comment[cs]=Vyvíjejte vizuálně databázové aplikace
Comment[de]=Visuelle Entwicklung von Datenbankanwendungen
Comment[en_GB]=Visually develop database applications
Comment[es]=Desarrollo visual de aplicaciones de bases de datos
Comment[fi]=Kehitä tietokantasovelluksia visuaalisesti
Comment[fr]=Développer visuellement des applications de bases de données
Comment[gl]=Desenvolva visualmente aplicativos de base de datos.
Comment[it]=Sviluppa applicazioni per banche dati in modo visuale
Comment[nl]=Databasetoepassingen visueel ontwerpen
Comment[pl]=Twórz wizualne aplikacje bazodanowe
Comment[pt]=Desenvolver de forma visual aplicações de bases de dados
Comment[pt_BR]=Desenvolve aplicativos visuais de bancos de dados
Comment[sk]=Vizuálny vývoj databázových aplikácií
Comment[sv]=Utveckla databasprogram visuellt för skrivbordet
Comment[uk]=Візуальна розробка програм для роботи із базами даних
Comment[x-test]=xxVisually develop database applicationsxx
X-DocPath=kexi/index.html
X-KDE-NativeMimeType=application/x-kexiproject-sqlite
Categories=Qt;KDE;Office;Database;Development;

==> kexi_3.2.0.orig.tar.xz: kexi-3.2.0/src/data/org.kde.kexi.desktop.cmake <==
[Desktop Entry]
Name=Kexi
Name[ast]=Kexi
Name[ca]=Kexi
Name[ca@valencia]=Kexi
Name[cs]=Kexi
Name[de]=Kexi
Name[en_GB]=Kexi
Name[es]=Kexi
Name[fi]=Kexi
Name[fr]=Kexi
Name[gl]=Kexi
Name[ia]=Kexi
Name[it]=Kexi
Name[ja]=Kexi
Name[nb]=Kexi
Name[nl]=Kexi
Name[pl]=Kexi
Name[pt]=Kexi
Name[pt_BR]=Kexi
Name[ru]=Kexi
Name[se]=Kexi
Name[sk]=Kexi
Name[sv]=Kexi
Name[uk]=Kexi
Name[x-test]=xxKexixx
Name[zh_CN]=Kexi
Type=Application
Exec=kexi-@KEXI_DISTRIBUTION_VERSION@ %f
Icon=kexi-@KEXI_DISTRIBUTION_VERSION@
MimeType=application/x-kexiproject-sqlite;application/x-kexiproject-shortcut;application/x-kexiproject-sqlite3;application/x-sqlite3;application/x-kexi-connectiondata;text/csv;text/tab-separated-values;application/vnd.oasis.opendocument.spreadsheet;application/vnd.oasis.opendocument.text;application/x-msaccess;application/vnd.oasis.opendocument.database;
Terminal=false
GenericName=Visual database apps builder
GenericName[ca]=Constructor visual d'aplicacions de bases de dades
GenericName[ca@valencia]=Constructor visual d'aplicacions de bases de dades
GenericName[de]=Visuelle Erstellung von Datenbankanwendungen
GenericName[en_GB]=Visual database apps builder
GenericName[es]=Constructor visual de aplicaciones de bases de datos
GenericName[fi]=Visuaalinen tietokantasovellusten luonti
GenericName[fr]=Constructeur d'applications de bases de données visuel
GenericName[gl]=Construtor visual de aplicativos de base de datos
GenericName[it]=Generatore visuale di applicazioni di banche dati
GenericName[nl]=Visuele database van bouwer van apps
GenericName[pl]=Tworzenie wizualnych aplikacji baz danych
GenericName[pt]=Construtor visual de aplicações de bases de dados
GenericName[pt_BR]=Construtor visual de aplicativos de banco de dados
GenericName[sk]=Vizuálny tvorca databázových aplikácií
GenericName[sv]=Visuellt byggverktyg för databasprogram
GenericName[uk]=Програма для побудови візуальних обробників баз даних
GenericName[x-test]=xxVisual database apps builderxx
GenericName[zh_CN]=可视化数据库应用程序生成器
Comment=Visually develop database applications
Comment[ca]=Desenvolupament visual d'aplicacions de bases de dades
Comment[ca@valencia]=Desenvolupament visual d'aplicacions de bases de dades
Comment[cs]=Vyvíjejte vizuálně databázové aplikace
Comment[de]=Visuelle Entwicklung von Datenbankanwendungen
Comment[en_GB]=Visually develop database applications
Comment[es]=Desarrollo visual de aplicaciones de bases de datos
Comment[fi]=Kehitä tietokantasovelluksia visuaalisesti
Comment[fr]=Développer visuellement des applications de bases de données
Comment[gl]=Desenvolva visualmente aplicativos de base de datos.
Comment[it]=Sviluppa applicazioni per banche dati in modo visuale
Comment[nl]=Databasetoepassingen visueel ontwerpen
Comment[pl]=Twórz wizualne aplikacje bazodanowe
Comment[pt]=Desenvolver de forma visual aplicações de bases de dados
Comment[pt_BR]=Desenvolve aplicativos visuais de bancos de dados
Comment[sk]=Vizuálny vývoj databázových aplikácií
Comment[sv]=Utveckla databasprogram visuellt för skrivbordet
Comment[uk]=Візуальна розробка програм для роботи із базами даних
Comment[x-test]=xxVisually develop database applicationsxx
Comment[zh_CN]=可视化开发数据库应用程序
X-DocPath=kexi-@KEXI_DISTRIBUTION_VERSION@/index.html
X-KDE-NativeMimeType=application/x-kexiproject-sqlite
Categories=Qt;KDE;Office;Database;Development;
